# Change log for libcrc

This document describes the changes between the different versions of the libraries. Please note that no change log is available for versions prior to version 2.0.

## Changes between development version and version 2.0

* Function [`crc_64_ecma()`](doc/crc_64_ecma.md) added
* Function [`crc_64_we()`](doc/crc_64_we.md) added
* Function [`update_crc_64()`](doc/update_crc_64.md) added
* Optimized CRC calculations by removing temporary variables in the loops
